; Playing around with bit shifting (or seizure causation :) 
      processor 6502 
      include "vcs.h" 
      include "macro.h" 


PATTERNPF0   = $80          ; storage location (1st byte in RAM) 
PATTERNPF1   = $81 
PATTERNPF2   = $82 
TIMER1     = $83 
COLOROFFSET   = $84 
TIMER2     = $85 
ROTATED     = $86 
TIMETOCHANGE  = 2           ; speed of "animation" - change as desired 
TIMER2CHANGE  = 20          ; speed of "scroll            


      SEG 
      ORG $F000 

Reset 
; Clear RAM and all TIA registers 

        ldx #0 
        lda #0 
Clear      sta 0,x 
        inx 
        bne Clear 

    ;------------------------------------------------ 
    ; Once-only initialisation... 

        lda #0 
        sta TIMER1 
        sta TIMER2 
        sta ROTATED 
        lda #%01010101 
        sta PATTERNPF0 
        lda #%10101010 
        sta PATTERNPF1 
        
        sta COLUPF       ; set the playfield colour 

StartOfFrame 

  ; Start of vertical blank processing 

      lda #0 
      sta VBLANK 

      lda #2 
      sta VSYNC 
      
        ; 3 scanlines of VSYNCH signal... 

        sta WSYNC 
        sta WSYNC 
        sta WSYNC 

      lda #0 
      sta VSYNC      

        ; 37 scanlines of vertical blank... 
      
        ldx #0 
VerticalBlank  sta WSYNC 
        inx 
        cpx #35 
        bne VerticalBlank 

        lda #0 
        sta ROTATED 

INIT      ldx #$00 
        stx COLUBK 
        ldx #0 

        ldy TIMER2 
        cpy #TIMER2CHANGE 
        bne NOROTATE 
        
        inc ROTATED 
        
        lda #0 
        sta TIMER2       
        clc       ;important :) 
        rol PATTERNPF0 ;shift bits left 
        bcs ORPF0 

RORPF1     clc       ;important :) 
        ror PATTERNPF1  ;shift bits right 
        bcs ORPF1 
        jmp NOROTATE 

ORPF1      lda #%10000000  
        ora PATTERNPF1  ;reset high bit on carry  
        sta PATTERNPF1 
        jmp NOROTATE      
    
ORPF0      lda #%00000001 
        ora PATTERNPF0  ;reset low bit on carry 
        sta PATTERNPF0 
        jmp RORPF1       


NOROTATE    inc TIMER2 

        ldy TIMER1 
        cpy #TIMETOCHANGE 
        bne notyet 

        inc COLOROFFSET 
        ldy COLOROFFSET 
        lda #0 
        sta TIMER1 

notyet 
        inc TIMER1 
        ldy COLOROFFSET 

        
        sta WSYNC 
        lda ROTATED  ;need to wait 1 more line when no 
        cmp #1    ;rotation occurs, would a timer be better for this? 
        beq DrawField 
        sta WSYNC 

DrawField    lda #0 
        sta ROTATED 
    
Top       sty COLUPF 
        lda PATTERNPF0 
        sta PF0 
        sta PF2 
        lda PATTERNPF1 
        sta PF1 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC        

        lda PATTERNPF1 
        sta PF0 
        sta PF2 
        lda PATTERNPF0 
        sta PF1 
        sty COLUPF 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC 
        inx 
        iny 
        sta WSYNC        
        cpx #192 
        bne Top 

DONEFRAME    lda #0 
        sta COLUBK 
        sta COLUPF       
        lda #%01000010 
        sta VBLANK           ; end of screen - enter blanking 

        ldx #0 
Overscan    sta WSYNC 
        lda #0 
        inx 
        cpx #30 
        bne Overscan 
        
        

        jmp StartOfFrame 


      ORG $FFFA 

      .word Reset      ; NMI 
      .word Reset      ; RESET 
      .word Reset      ; IRQ 

    END